@@ -47,7 +47,6 @@ from .apigee_edge import (
     _test_app_callback_url,
     _test_app_credentials,
     identity_service_base_url,
-    keycloak_realm_urls,
     nhsd_apim_pre_create_app,
     nhsd_apim_proxy_url,
     test_app,
@@ -85,9 +84,9 @@ def _nhsd_apim_auth_token_data(
     _test_app_callback_url,
     _keycloak_client_credentials,
     identity_service_base_url,
-    keycloak_realm_urls,
     jwt_private_key_pem,
     jwt_public_key_id,
+    apigee_environment,
 ):
     """
     Main entrypoint to pytest_nhsd_apim.
@@ -110,6 +109,7 @@ def _nhsd_apim_auth_token_data(
                 _test_app_credentials["consumerKey"],
                 jwt_private_key_pem,
                 jwt_public_key_id,
+                apigee_environment,
                 force_new_token=nhsd_apim_authorization["force_new_token"],
             )
             return token_data
@@ -131,6 +131,7 @@ def _nhsd_apim_auth_token_data(
             _test_app_callback_url,
             backend_provider_names[access],
             login_form,
+            apigee_environment,
             force_new_token=nhsd_apim_authorization["force_new_token"],
         )
 
@@ -143,7 +144,7 @@ def _nhsd_apim_auth_token_data(
             jwt_private_key_pem,
             jwt_public_key_id,
             backend_provider_names[access],
-            keycloak_realm_urls,
+            apigee_environment,
             force_new_token=nhsd_apim_authorization["force_new_token"],
         )
     else:
